package esi.examwh.dao;

import java.util.List;

import javax.persistence.NoResultException;
import javax.persistence.Query;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;
import org.hibernate.query.NativeQuery;

import com.plw.util.Common;
import com.plw.util.DataNotFoundException;

import esi.examwh.dao.common.CommonLog;
import esi.examwh.dao.common.LOG_LEVEL;
import esi.examwh.model.Person;
import esi.examwh.model.common.TYPE_DATA_STATUS;
import esi.examwh.model.common.TYPE_EXAMINATION;

public class PersonDAO {
	/**
	 * @param MyHSs
	 * @param ao_Person
	 * @param as_UserName
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Person Add(Session MyHSs,Person ao_Person, String as_UserName, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Add", "[START] @@@");
		//PermissionService.isAddPermission(ao_Person.getOwnerSUID(), ao_Person.getOwnerSGID(), SUID, SGID);
		try {
		
			ao_Person.setModifyTime(Common.GetCurrTime());
			ao_Person.setModifyUser(as_UserName);
			ao_Person.setCreateTime(Common.GetCurrTime());
			ao_Person.setCreateUser(as_UserName);
			ObjectDAO.Add(MyHSs, ao_Person);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Add", "[Ready][ID:" + ao_Person.getPersonID() + "]");
			return ao_Person;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "Add", "[ID:" + ao_Person.getPersonID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}

	/**
	 * @param MyHSs
	 * @param ao_Person
	 * @param as_UserName
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Person Disable(Session MyHSs, Person ao_Person, String as_UserName, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Disable", "[START] @@@");
		//PermissionService.isAddPermission(ao_Person.getOwnerSUID(), ao_Person.getOwnerSGID(), SUID, SGID);
		try {
			
			ao_Person.setDataStatus(TYPE_DATA_STATUS.STATUS_DISABLE);
			ao_Person.setDeletedUser(as_UserName);
			ao_Person.setDeletedTime(Common.GetCurrTime());
			ObjectDAO.Disable(MyHSs, ao_Person);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Disable", "[Ready][ID:" + ao_Person.getPersonID() + "]");
			return ao_Person;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "Disable", "[ID:" +ao_Person.getPersonID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}

	/**
	 * @param MyHSs
	 * @param ao_Person
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Person Delete(Session MyHSs, Person ao_Person, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Delete", "[START] @@@");
		//PermissionService.isAddPermission(ao_Person.getOwnerSUID(), ao_Person.getOwnerSGID(), SUID, SGID);
		try {
			ObjectDAO.Delete(MyHSs, ao_Person);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Delete", "[ID:" + ao_Person.getPersonID() + "]");
			return ao_Person;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "Delete", "[ID:" + ao_Person.getPersonID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}

	/**
	 * @param MyHSs
	 * @param ao_Person
	 * @param as_UserName
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Person Modify(Session MyHSs, Person ao_Person, String as_UserName, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Modify", "[START] @@@");
		//PermissionService.isAddPermission(ao_Person.getOwnerSUID(), ao_Address.getOwnerSGID(), SUID, SGID);
		try {
			ao_Person.setModifyTime(Common.GetCurrTime());
			ao_Person.setModifyUser(as_UserName);
			ObjectDAO.Modify(MyHSs, ao_Person);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "Modify", "[ID:" + ao_Person.getPersonID() + "]");
			return ao_Person;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "Modify", "[ID:" + ao_Person.getPersonID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}
	/**
	 * @param MyHSs
	 * @param ai_PersonID
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws DataNotFoundException
	 */
	public static Person GetByID(Session MyHSs, Integer ai_PersonID, Integer SUID, Integer SGID) throws DataNotFoundException {
		Person thePerson = null;
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetByID", "[START] @@@");
		CriteriaBuilder builder = MyHSs.getCriteriaBuilder();
		CriteriaQuery<Person> criteria = builder.createQuery(Person.class);
		criteria.where(builder.equal(criteria.from(Person.class).get("personID"), ai_PersonID));	
		Query query = MyHSs.createQuery(criteria);
		query.setFirstResult(0);
		query.setMaxResults(1);
		try {
			thePerson = (Person) query.getSingleResult();
			if (thePerson != null) {
				return thePerson;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "GetByID", "[Not Found][ID:" + ai_PersonID + "]");
				throw new DataNotFoundException("Person [" + ai_PersonID + "] is not found.");
			}
		} catch (DataNotFoundException ex) {
			throw ex;
		} catch (NoResultException ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "GetByID", "[Not Found][ID:" + ai_PersonID + "]");
			throw new DataNotFoundException("Person [" + ai_PersonID + "] is not found.");
		} catch (Exception ex) {
			throw ex;
		} finally {
		}
	}
	public static Person GetBySystemUserID(Session MyHSs, Integer ai_SystemUserID, Integer SUID, Integer SGID) throws DataNotFoundException {
		Person thePerson = null;
		List<Person> PersonList;
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetByID", "[START] @@@");
		Criteria MyHC;
		MyHC = MyHSs.createCriteria(Person.class).add(Restrictions.eq("systemUserID", ai_SystemUserID));
		MyHC.setFirstResult(0);
		MyHC.setMaxResults(1);
		PersonList = MyHC.list();
		if (PersonList.isEmpty() != true) {
			thePerson = PersonList.get(0);
			return thePerson;
		} else {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "GetByID", "[Not Found] @@@");
			throw new DataNotFoundException("Person [" + ai_SystemUserID + "] is not found.");
		}
	}
	/**
	 * @param ai_CommandType
	 * @param SUID
	 * @param SGID
	 * @param StatusList
	 * @return
	 */
	public static String GenSQLALL(int ai_CommandType, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		return sb_SQLCommand.toString();
	}
	/**
	 * @param MyHSs
	 * @param SUID
	 * @param SGID
	 * @param StatusList
	 * @return
	 * @throws DataNotFoundException
	 * @throws Exception
	 */
	public static int GetSizeAll(Session MyHSs,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeAll", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLALL(10,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeAll", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeAll", "[" + RowCount.intValue() + "] Of Person By All [END] @@@");
		return RowCount.intValue();
	}
	/**
	 * @param MyHSs
	 * @param SUID
	 * @param SGID
	 * @param BeginRow
	 * @param MaxRow
	 * @param StatusList
	 * @return
	 * @throws DataNotFoundException
	 * @throws Exception
	 */
	public static List<Person> FindAll(Session MyHSs,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByAll", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLALL(20,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByAll", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByAll", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By All is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByTitleNamePersonNamePersonLastName(int ai_CommandType,String as_TitleName,String as_PersonName,String as_PersonLastName, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_TitleName != null){
			sb_SQLCommand.append("AND PS.PS_PrefixName = '"+as_TitleName+"' ");	
		}
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name = '"+as_PersonName+"' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName = '"+as_PersonLastName+"' ");	
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByTitleNamePersonNamePersonLastName(Session MyHSs,String as_TitleName,String as_PersonName,String as_PersonLastName,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByTitleNamePersonNamePersonLastName(10,as_TitleName, as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByTitleNamePersonNamePersonLastName(Session MyHSs,String as_TitleName,String as_PersonName,String as_PersonLastName,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByTitleNamePersonNamePersonLastName", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByTitleNamePersonNamePersonLastName(20,as_TitleName,as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByTitleNamePersonNamePersonLastName", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByTitleNamePersonNamePersonLastName", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByCodeTitleNamePersonNamePersonLastName(int ai_CommandType,String as_Code,String as_TitleName,String as_PersonName,String as_PersonLastName, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_TitleName != null){
			sb_SQLCommand.append("AND PS.PS_PrefixName = '"+as_TitleName+"' ");	
		}
		if(as_Code != null){
			sb_SQLCommand.append("AND PS.PS_Code = '"+as_Code+"' ");	
		}
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name = '"+as_PersonName+"' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName = '"+as_PersonLastName+"' ");	
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByCodeTitleNamePersonNamePersonLastName(Session MyHSs,String as_Code,String as_TitleName,String as_PersonName,String as_PersonLastName,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCodeTitleNamePersonNamePersonLastName", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByCodeTitleNamePersonNamePersonLastName(10,as_Code,as_TitleName, as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCodeTitleNamePersonNamePersonLastName", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCodeTitleNamePersonNamePersonLastName", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByCodeTitleNamePersonNamePersonLastName(Session MyHSs,String as_Code,String as_TitleName,String as_PersonName,String as_PersonLastName,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByCodeTitleNamePersonNamePersonLastName", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByCodeTitleNamePersonNamePersonLastName(20,as_Code,as_TitleName,as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByCodeTitleNamePersonNamePersonLastName", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByCodeTitleNamePersonNamePersonLastName", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor(int ai_CommandType,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");	
		}
		if(ai_FilterSubjectID != null){
			sb_SQLCommand.append("AND PS.PersonID Not IN ( ");
				sb_SQLCommand.append("SELECT ESDFE.PersonID ");
				sb_SQLCommand.append("FROM ESDFormEditor ESDFE ");
				sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDFE.ExamScheduleDetailID ");
				sb_SQLCommand.append("WHERE ESDFE.ESDFE_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_SubjectID = "+ai_FilterSubjectID+" ");
			sb_SQLCommand.append(" ) ");
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor(10, as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor(20,as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormEditor", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName FilterSubjectID InESDFormEditor is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator(int ai_CommandType,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");	
		}
		if(ai_FilterSubjectID != null){
			sb_SQLCommand.append("AND PS.PersonID Not IN ( ");
				sb_SQLCommand.append("SELECT ESDFC.PersonID ");
				sb_SQLCommand.append("FROM ESDFormCollator ESDFC ");
				sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDFC.ExamScheduleDetailID ");
				sb_SQLCommand.append("WHERE ESDFC.ESDFC_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_SubjectID = "+ai_FilterSubjectID+" ");
			sb_SQLCommand.append(" ) ");
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator(10, as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator(20,as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormCollator", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName FilterSubjectID InESDFormCollator is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	public static String GenSQLByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator(int ai_CommandType,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");	
		}
		if(ai_FilterSubjectID != null){
			sb_SQLCommand.append("AND PS.PersonID Not IN ( ");
				sb_SQLCommand.append("SELECT SJC.PersonID ");
				sb_SQLCommand.append("FROM SubjectCollator SJC ");
				
				sb_SQLCommand.append("WHERE SJC.SJC_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				
				sb_SQLCommand.append("AND SJC.SubjectID = "+ai_FilterSubjectID+" ");
			sb_SQLCommand.append(" ) ");
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator(10, as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator(20,as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName FilterSubjectID In SubjectCollator is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	public static String GenSQLByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor(int ai_CommandType,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");	
		}
		if(ai_FilterSubjectID != null){
			sb_SQLCommand.append("AND PS.PersonID Not IN ( ");
				sb_SQLCommand.append("SELECT SJE.PersonID ");
				sb_SQLCommand.append("FROM SubjectEditor SJE ");
				
				sb_SQLCommand.append("WHERE SJE.SJE_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				
				sb_SQLCommand.append("AND SJE.SubjectID = "+ai_FilterSubjectID+" ");
			sb_SQLCommand.append(" ) ");
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor(10, as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor(20,as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInSubjectEditor", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInSubjectCollator", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName FilterSubjectID In SubjectCollatoris not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByCollatorExamScheduleID(int ai_CommandType,Integer ai_ExamScheduleID  ,Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(DISTINCT PS.PersonID) ");
		} else {
			sb_SQLCommand.append("SELECT DISTINCT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("JOIN ESDFormCollator ESDFC ON ESDFC.PersonID = PS.PersonID ");
		sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDFC.ExamScheduleDetailID ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(ai_ExamScheduleID != null){
			sb_SQLCommand.append("AND  ESD.ESD_CopiedExamScheduleID = "+ai_ExamScheduleID+" ");
		}
		
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByCollatorExamScheduleID(Session MyHSs,Integer ai_ExamScheduleID ,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCollatorExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByCollatorExamScheduleID(10,ai_ExamScheduleID ,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCollatorExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCollatorExamScheduleID", "[" + RowCount.intValue() + "] Of Person By ExamScheduleID ["+ai_ExamScheduleID+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByCollatorExamScheduleID(Session MyHSs,Integer ai_ExamScheduleID ,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByCollatorExamScheduleID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByCollatorExamScheduleID(20,ai_ExamScheduleID ,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByCollatorExamScheduleID", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByCollatorExamScheduleID", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By ExamScheduleID ");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByEditorExamScheduleID(int ai_CommandType,Integer ai_ExamScheduleID  ,Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(DISTINCT PS.PersonID) ");
		} else {
			sb_SQLCommand.append("SELECT DISTINCT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("JOIN ESDFormEditor ESDFE ON ESDFE.PersonID = PS.PersonID ");
		sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDFE.ExamScheduleDetailID ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(ai_ExamScheduleID != null){
			sb_SQLCommand.append("AND  ESD.ESD_CopiedExamScheduleID = "+ai_ExamScheduleID+" ");
		}
		
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByEditorExamScheduleID(Session MyHSs,Integer ai_ExamScheduleID ,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByEditorExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByEditorExamScheduleID(10,ai_ExamScheduleID ,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByEditorExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByEditorExamScheduleID", "[" + RowCount.intValue() + "] Of Person By ExamScheduleID ["+ai_ExamScheduleID+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByEditorExamScheduleID(Session MyHSs,Integer ai_ExamScheduleID ,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByEditorExamScheduleID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByEditorExamScheduleID(20,ai_ExamScheduleID ,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByEditorExamScheduleID", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByEditorExamScheduleID", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By ExamScheduleID ");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeEditorNameEditorLastName(int ai_CommandType ,String as_SubjectCode , String as_SubjectName, Integer ai_ExamYearID, Integer ai_ExamSemesterID, Integer ai_ExamRoundID, Integer ai_ExamTermID,TYPE_EXAMINATION ai_ExaminationType, String as_PersonName, String as_PersonLastName,  Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(DISTINCT PS.PersonID) ");
		} else {
			sb_SQLCommand.append("SELECT DISTINCT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("JOIN ESDFormEditor ESDFE ON ESDFE.PersonID = PS.PersonID ");
		sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDFE.ExamScheduleDetailID AND ESD.ESD_DataStatus NOT IN (411,511) ");
		sb_SQLCommand.append("JOIN ExamSchedule ES ON ES.ExamScheduleID = ESD.ESD_CopiedExamScheduleID AND ES.ES_DataStatus NOT IN (411,511) ");
		sb_SQLCommand.append("JOIN Subject SJ ON SJ.SubjectID = ESD.ESD_SubjectID AND SJ.SJ_DataStatus NOT IN (411,511) ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(ai_ExamYearID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamYearID = "+ai_ExamYearID+" ");
		}
		if(ai_ExamSemesterID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamSemesterID = "+ai_ExamSemesterID+" ");
		}
		if(ai_ExamRoundID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamRoundID = "+ai_ExamRoundID+" ");
		}
		if(ai_ExamTermID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamTermID = "+ai_ExamTermID+" ");
		}
		if(ai_ExaminationType != null){
			sb_SQLCommand.append("AND  ES.ES_ExaminationType = "+ai_ExaminationType.getValue()+" ");
		}
		if(as_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = '"+as_SubjectCode+"' ");
		}
		if(as_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name LIKE '%"+as_SubjectName+"%' ");
		}
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");
		}
		
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeEditorNameEditorLastName(Session MyHSs ,String as_SubjectCode , String as_SubjectName, Integer ai_ExamYearID, Integer ai_ExamSemesterID, Integer ai_ExamRoundID, Integer ai_ExamTermID,TYPE_EXAMINATION ai_ExaminationType, String as_PersonName, String as_PersonLastName,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByEditorExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeEditorNameEditorLastName(10,as_SubjectCode , as_SubjectName ,  ai_ExamYearID, ai_ExamSemesterID,ai_ExamRoundID,ai_ExamTermID,ai_ExaminationType,as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByEditorExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamYearIDExamSemesterIDExamRoundIDExaminationTypeEditorNameEditorLastName", "[" + RowCount.intValue() + "] Of EsdformEditor By  SubjectCode ["+as_SubjectCode+"] SubjectName ["+as_SubjectName+"] ExamYearID ["+ai_ExamYearID+"] ExamSemesterID ["+ai_ExamSemesterID+"] ExamRoundID ["+ai_ExamRoundID+"] ExaminationType ["+ai_ExaminationType+"] PersonName ["+as_PersonName+"] PersonLastName ["+as_PersonLastName+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeEditorNameEditorLastName(Session MyHSs ,String as_SubjectCode , String as_SubjectName, Integer ai_ExamYearID, Integer ai_ExamSemesterID, Integer ai_ExamRoundID, Integer ai_ExamTermID,TYPE_EXAMINATION ai_ExaminationType, String as_PersonName, String as_PersonLastName,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByEditorExamScheduleID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeEditorNameEditorLastName(20,as_SubjectCode , as_SubjectName ,  ai_ExamYearID,ai_ExamSemesterID,ai_ExamRoundID, ai_ExamTermID,ai_ExaminationType,as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExaminationTypeEditorNameEditorLastName", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExaminationTypeEditorNameEditorLastName", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By ExamScheduleID ");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeCollectorNameCollectorLastName(int ai_CommandType ,String as_SubjectCode , String as_SubjectName, Integer ai_ExamYearID, Integer ai_ExamSemesterID, Integer ai_ExamRoundID, Integer ai_ExamTermID,TYPE_EXAMINATION ai_ExaminationType, String as_PersonName, String as_PersonLastName,  Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(DISTINCT PS.PersonID) ");
		} else {
			sb_SQLCommand.append("SELECT DISTINCT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("JOIN ESDFormCollator ESDFC ON ESDFC.PersonID = PS.PersonID ");
		sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDFC.ExamScheduleDetailID AND ESD.ESD_DataStatus NOT IN (411,511) ");
		sb_SQLCommand.append("JOIN ExamSchedule ES ON ES.ExamScheduleID = ESD.ESD_CopiedExamScheduleID  AND ES.ES_DataStatus NOT IN (411,511) ");
		sb_SQLCommand.append("JOIN Subject SJ ON SJ.SubjectID = ESD.ESD_SubjectID  AND SJ.SJ_DataStatus NOT IN (411,511)");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(ai_ExamYearID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamYearID = "+ai_ExamYearID+" ");
		}
		if(ai_ExamSemesterID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamSemesterID = "+ai_ExamSemesterID+" ");
		}
		if(ai_ExamRoundID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamRoundID = "+ai_ExamRoundID+" ");
		}
		if(ai_ExamTermID != null){
			sb_SQLCommand.append("AND  ES.ES_ExamTermID = "+ai_ExamTermID+" ");
		}
		if(ai_ExaminationType != null){
			sb_SQLCommand.append("AND  ES.ES_ExaminationType = "+ai_ExaminationType.getValue()+" ");
		}
		if(as_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = '"+as_SubjectCode+"' ");
		}
		if(as_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name LIKE '%"+as_SubjectName+"%' ");
		}
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeCollectorNameCollectorLastName(Session MyHSs ,String as_SubjectCode , String as_SubjectName, Integer ai_ExamYearID, Integer ai_ExamSemesterID, Integer ai_ExamRoundID, Integer ai_ExamTermID,TYPE_EXAMINATION ai_ExaminationType, String as_PersonName, String as_PersonLastName,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCollatorExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeCollectorNameCollectorLastName(10,as_SubjectCode , as_SubjectName ,  ai_ExamYearID, ai_ExamSemesterID,ai_ExamRoundID,ai_ExamTermID,ai_ExaminationType,as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByCollatorExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamYearIDExamSemesterIDExamRoundIDExaminationTypeEditorNameEditorLastName", "[" + RowCount.intValue() + "] Of EsdformCollator By  SubjectCode ["+as_SubjectCode+"] SubjectName ["+as_SubjectName+"] ExamYearID ["+ai_ExamYearID+"] ExamSemesterID ["+ai_ExamSemesterID+"] ExamRoundID ["+ai_ExamRoundID+"] ExaminationType ["+ai_ExaminationType+"] PersonName ["+as_PersonName+"] PersonLastName ["+as_PersonLastName+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeCollectorNameCollectorLastName(Session MyHSs ,String as_SubjectCode , String as_SubjectName, Integer ai_ExamYearID, Integer ai_ExamSemesterID, Integer ai_ExamRoundID, Integer ai_ExamTermID,TYPE_EXAMINATION ai_ExaminationType, String as_PersonName, String as_PersonLastName,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExaminationTypeCollectorNameCollectorLastName", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExamTermIDExaminationTypeCollectorNameCollectorLastName(20,as_SubjectCode , as_SubjectName ,  ai_ExamYearID,ai_ExamSemesterID,ai_ExamRoundID,ai_ExamTermID,ai_ExaminationType,as_PersonName,as_PersonLastName,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByCollatorExamScheduleID", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindBySubjectCodeSubjectNameExamYearIDExamSemesterIDExamRoundIDExaminationTypeCollectorNameCollectorLastName", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By ExamScheduleID ");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByExamFormConditionID(int ai_CommandType,Integer ai_ExamFormConditionID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if((ai_ExamFormConditionID != null)){
			sb_SQLCommand.append("AND PS.PersonID IN ( ");
				sb_SQLCommand.append("SELECT ECCD.ECCD_PersonID ");
				sb_SQLCommand.append("FROM ExamCreatorCondition ECCD ");
				sb_SQLCommand.append("WHERE ECCD.ECCD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ECCD.ECCD_ExamFormConditionID = "+ai_ExamFormConditionID+" ");
				
			sb_SQLCommand.append(" ) ");
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByExamFormConditionID(Session MyHSs,Integer ai_ExamFormConditionID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamFormConditionID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByExamFormConditionID(10,ai_ExamFormConditionID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamFormConditionID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamFormConditionID", "[" + RowCount.intValue() + "] Of Person By ExamFormConditionID["+ai_ExamFormConditionID+"]  [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByExamFormConditionID(Session MyHSs,Integer ai_ExamFormConditionID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByExamFormConditionID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByExamFormConditionID(20,ai_ExamFormConditionID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByExamFormConditionID", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByExamFormConditionID", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person ByBehaviorCode BehaviorName BehaviorDetail is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByNameLastNameFilterPersonIDList(int ai_CommandType,String as_Name,String as_LastName,List<Integer> ai_PersonIDList, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_Name != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_Name+"%' ");
		}
		if(as_LastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_LastName+"%' ");
		}
		if(ai_PersonIDList != null && ai_PersonIDList.size() > 0){
			sb_SQLCommand.append("AND PS.PersonID NOT IN ( ");
			for(int i=0;i<ai_PersonIDList.size();i++){
				if(i != 0){
					sb_SQLCommand.append(", ");
				}
				sb_SQLCommand.append(ai_PersonIDList.get(i));
			}
			sb_SQLCommand.append(") ");
		}
		return sb_SQLCommand.toString();
	}

	public static int GetSizeByNameLastNameFilterPersonIDList(Session MyHSs,String as_Name,String as_LastName,List<Integer> ai_PersonIDList,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByNameLastNameFilterPersonIDList", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByNameLastNameFilterPersonIDList(10,as_Name,as_LastName,ai_PersonIDList,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByNameLastNameFilterPersonIDList", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByNameLastNameFilterPersonIDList", "[" + RowCount.intValue() + "] Of Person By All [END] @@@");
		return RowCount.intValue();
	}

	public static List<Person> FindByNameLastNameFilterPersonIDList(Session MyHSs,String as_Name,String as_LastName,List<Integer> ai_PersonIDList,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByNameLastNameFilterPersonIDList", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByNameLastNameFilterPersonIDList(20,as_Name,as_LastName,ai_PersonIDList,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByNameLastNameFilterPersonIDList", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByNameLastNameFilterPersonIDList", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By All is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLBySelectorExamScheduleID(int ai_CommandType,Integer ai_ExamScheduleID  ,Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(DISTINCT PS.PersonID) ");
		} else {
			sb_SQLCommand.append("SELECT DISTINCT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("JOIN ESDItemSelector ESDIS ON ESDIS.PersonID = PS.PersonID ");
		sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDIS.ExamScheduleDetailID ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(ai_ExamScheduleID != null){
			sb_SQLCommand.append("AND  ESD.ESD_CopiedExamScheduleID = "+ai_ExamScheduleID+" ");
		}
		
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySelectorExamScheduleID(Session MyHSs,Integer ai_ExamScheduleID ,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeBySelectorExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySelectorExamScheduleID(10,ai_ExamScheduleID ,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeBySelectorExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeBySelectorExamScheduleID", "[" + RowCount.intValue() + "] Of Person By ExamScheduleID ["+ai_ExamScheduleID+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindBySelectorExamScheduleID(Session MyHSs,Integer ai_ExamScheduleID ,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindBySelectorExamScheduleID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySelectorExamScheduleID(20,ai_ExamScheduleID ,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindBySelectorExamScheduleID", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindBySelectorExamScheduleID", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By ExamScheduleID ");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector(int ai_CommandType,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");	
		}
		if(ai_FilterSubjectID != null){
			sb_SQLCommand.append("AND PS.PersonID Not IN ( ");
				sb_SQLCommand.append("SELECT ESDIS.PersonID ");
				sb_SQLCommand.append("FROM ESDItemSelector ESDIS ");
				sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = ESDIS.ExamScheduleDetailID ");
				sb_SQLCommand.append("WHERE ESDIS.ESDIS_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_SubjectID = "+ai_FilterSubjectID+" ");
			sb_SQLCommand.append(" ) ");
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector(10, as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_FilterSubjectID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector(20,as_PersonName,as_PersonLastName,ai_FilterSubjectID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameFilterSubjectIDInESDFormSelector", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName FilterSubjectID InESDFormSelector is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType(int ai_CommandType,String as_PersonName,String as_PersonLastName,Integer ai_ExamYearID,Integer ai_ExamTermID,TYPE_EXAMINATION ae_ExaminationType, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(as_PersonName != null){
			sb_SQLCommand.append("AND PS.PS_Name LIKE '%"+as_PersonName+"%' ");	
		}
		if(as_PersonLastName != null){
			sb_SQLCommand.append("AND PS.PS_LastName LIKE '%"+as_PersonLastName+"%' ");	
		}
//		if(ai_FilterSubjectID != null){
			sb_SQLCommand.append("AND PS.PersonID IN ( ");
				sb_SQLCommand.append("SELECT EI.EI_ExamCreator ");
				sb_SQLCommand.append("FROM ExamItem EI ");
				sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = EI.EI_ExamScheduleDetailID ");
				sb_SQLCommand.append("JOIN ExamSchedule ES ON ES.ExamScheduleID = ESD.ESD_CopiedExamScheduleID ");
				sb_SQLCommand.append("WHERE EI.EI_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ES.ES_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				if(ai_ExamYearID != null){
					sb_SQLCommand.append("AND ES.ES_ExamYearID = "+ai_ExamYearID+" ");
				}
				if(ai_ExamTermID != null){
					sb_SQLCommand.append("AND ES.ES_ExamTermID = "+ai_ExamTermID+" ");
				}
				if(ae_ExaminationType != null){
					sb_SQLCommand.append("AND ES.ES_ExaminationType = "+ae_ExaminationType.getValue()+" ");
				}
			sb_SQLCommand.append(" ) ");
//		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY PS.PS_Name ,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_ExamYearID,Integer ai_ExamTermID,TYPE_EXAMINATION ae_ExaminationType,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType(10, as_PersonName,as_PersonLastName,ai_ExamYearID,ai_ExamTermID,ae_ExaminationType,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType", "[" + RowCount.intValue() + "] Of Person By PersonName PersonLastName FilterSubjectID [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType(Session MyHSs,String as_PersonName,String as_PersonLastName,Integer ai_ExamYearID,Integer ai_ExamTermID,TYPE_EXAMINATION ae_ExaminationType,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType(20,as_PersonName,as_PersonLastName,ai_ExamYearID,ai_ExamTermID,ae_ExaminationType,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GenSQLByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByPersonNamePersonLastNameExamYearIDExamTermIDExaminationType", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person By PersonName PersonLastName FilterSubjectID InESDFormSelector is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLByExamScheduleDetailID(int ai_CommandType,Integer ai_ExamScheduleDetailID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT PS.* ");
		}
		sb_SQLCommand.append("FROM Person PS ");
		sb_SQLCommand.append("WHERE PS.PS_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if((ai_ExamScheduleDetailID != null)){
			sb_SQLCommand.append("AND PS.PersonID IN ( ");
				sb_SQLCommand.append("SELECT ECCD.ECCD_PersonID ");
				sb_SQLCommand.append("FROM ExamCreatorCondition ECCD ");
				sb_SQLCommand.append("JOIN ExamFormCondition EFCD ON ECCD.ECCD_ExamFormConditionID = EFCD.ExamFormConditionID ");
				sb_SQLCommand.append("WHERE ECCD.ECCD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND EFCD.EFCD_ExamScheduleDetailID = "+ai_ExamScheduleDetailID+" ");
				
			sb_SQLCommand.append(" ) ");
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY PS.PS_Name,PS.PS_LastName ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByExamScheduleDetailID(Session MyHSs,Integer ai_ExamScheduleDetailID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamScheduleDetailID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByExamScheduleDetailID(10,ai_ExamScheduleDetailID,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamScheduleDetailID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "GetSizeByExamScheduleDetailID", "[" + RowCount.intValue() + "] Of Person By ExamScheduleDetailID["+ai_ExamScheduleDetailID+"]  [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Person> FindByExamScheduleDetailID(Session MyHSs,Integer ai_ExamScheduleDetailID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByExamScheduleDetailID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByExamScheduleDetailID(20,ai_ExamScheduleDetailID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "PersonDAO", "FindByExamScheduleDetailID", ls_SQLCommand);
			NativeQuery<Person> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Person.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Person> PersonList = query.list();
			if (PersonList.isEmpty() != true) {
				return PersonList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "PersonDAO", "FindByExamScheduleDetailID", "[Not Found] @@@");
				throw new DataNotFoundException("Find Person FindByExamScheduleDetailID is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
}