package esi.examwh.dao;

import java.util.List;

import javax.persistence.NoResultException;
import javax.persistence.Query;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;

import org.hibernate.Session;
import org.hibernate.query.NativeQuery;

import com.plw.util.Common;
import com.plw.util.DataNotFoundException;

import esi.examwh.dao.common.CommonLog;
import esi.examwh.dao.common.LOG_LEVEL;
import esi.examwh.dao.common.PermissionService;
import esi.examwh.model.Subject;
import esi.examwh.model.common.TYPE_DATA_STATUS;
import esi.examwh.model.common.TYPE_ENABLE_STATUS;
import esi.examwh.model.common.TYPE_EXAMINATION;
import esi.examwh.model.common.TYPE_EXAMINATION_STATUS;

public class SubjectDAO {
	/**
	 * @param MyHSs
	 * @param ao_Subject
	 * @param as_UserName
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Subject Add(Session MyHSs,Subject ao_Subject, String as_UserName, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Add", "[START] @@@");
		//PermissionService.isAddPermission(ao_Subject.getOwnerSUID(), ao_Subject.getOwnerSGID(), SUID, SGID);
		try {
		
			ao_Subject.setModifyTime(Common.GetCurrTime());
			ao_Subject.setModifyUser(as_UserName);
			ao_Subject.setCreateTime(Common.GetCurrTime());
			ao_Subject.setCreateUser(as_UserName);
			ObjectDAO.Add(MyHSs, ao_Subject);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Add", "[Ready][ID:" + ao_Subject.getSubjectID() + "]");
			return ao_Subject;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "Add", "[ID:" + ao_Subject.getSubjectID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}

	/**
	 * @param MyHSs
	 * @param ao_Subject
	 * @param as_UserName
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Subject Disable(Session MyHSs, Subject ao_Subject, String as_UserName, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Disable", "[START] @@@");
		//PermissionService.isAddPermission(ao_Subject.getOwnerSUID(), ao_Subject.getOwnerSGID(), SUID, SGID);
		try {
			
			ao_Subject.setDataStatus(TYPE_DATA_STATUS.STATUS_DISABLE);
			ao_Subject.setDeletedUser(as_UserName);
			ao_Subject.setDeletedTime(Common.GetCurrTime());
			ObjectDAO.Disable(MyHSs, ao_Subject);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Disable", "[Ready][ID:" + ao_Subject.getSubjectID() + "]");
			return ao_Subject;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "Disable", "[ID:" +ao_Subject.getSubjectID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}

	/**
	 * @param MyHSs
	 * @param ao_Subject
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Subject Delete(Session MyHSs, Subject ao_Subject, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Delete", "[START] @@@");
		//PermissionService.isAddPermission(ao_Subject.getOwnerSUID(), ao_Subject.getOwnerSGID(), SUID, SGID);
		try {
			ObjectDAO.Delete(MyHSs, ao_Subject);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Delete", "[ID:" + ao_Subject.getSubjectID() + "]");
			return ao_Subject;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "Delete", "[ID:" + ao_Subject.getSubjectID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}

	/**
	 * @param MyHSs
	 * @param ao_Subject
	 * @param as_UserName
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws Exception
	 */
	public static Subject Modify(Session MyHSs, Subject ao_Subject, String as_UserName, Integer SUID, Integer SGID) throws Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Modify", "[START] @@@");
		//PermissionService.isAddPermission(ao_Subject.getOwnerSUID(), ao_Address.getOwnerSGID(), SUID, SGID);
		try {
			ao_Subject.setModifyTime(Common.GetCurrTime());
			ao_Subject.setModifyUser(as_UserName);
			ObjectDAO.Modify(MyHSs, ao_Subject);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "Modify", "[ID:" + ao_Subject.getSubjectID() + "]");
			return ao_Subject;
		} catch (Exception ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "Modify", "[ID:" + ao_Subject.getSubjectID() + "]>" + ex.toString());
			throw ex;
		} finally {
		}
	}
	/**
	 * @param MyHSs
	 * @param ai_SubjectID
	 * @param SUID
	 * @param SGID
	 * @return
	 * @throws DataNotFoundException
	 */
	public static Subject GetByID(Session MyHSs, Integer ai_SubjectID, Integer SUID, Integer SGID) throws DataNotFoundException {
		Subject theSubject = null;
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetByID", "[START] @@@");
		CriteriaBuilder builder = MyHSs.getCriteriaBuilder();
		CriteriaQuery<Subject> criteria = builder.createQuery(Subject.class);
		criteria.where(builder.equal(criteria.from(Subject.class).get("subjectID"), ai_SubjectID));	
		Query query = MyHSs.createQuery(criteria);
		query.setFirstResult(0);
		query.setMaxResults(1);
		try {
			theSubject = (Subject) query.getSingleResult();
			if (theSubject != null) {
				return theSubject;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "GetByID", "[Not Found][ID:" + ai_SubjectID + "]");
				throw new DataNotFoundException("Subject [" + ai_SubjectID + "] is not found.");
			}
		} catch (DataNotFoundException ex) {
			throw ex;
		} catch (NoResultException ex) {
			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "GetByID", "[Not Found][ID:" + ai_SubjectID + "]");
			throw new DataNotFoundException("Subject [" + ai_SubjectID + "] is not found.");
		} catch (Exception ex) {
			throw ex;
		} finally {
		}
	}
	
	public static Subject GetByCode(Session MyHSs, String as_SubjectCode,Integer SUID,Integer SGID,int... StatusList) throws Exception {
		Subject theSubject = null;
//		List<Subject> SubjectList;
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetByCode", "[START] @@@");
//		Criteria MyHC;
//		MyHC = MyHSs.createCriteria(Subject.class).add(Restrictions.eq("code", as_SubjectCode));
//		MyHC.setFirstResult(0);
//		MyHC.setMaxResults(1);
//		SubjectList = MyHC.list();
//		if (SubjectList.isEmpty() != true) {
//			theSubject = SubjectList.get(0);
//			return theSubject;
//		} else {
//			CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "GetByCode", "[Not Found] @@@");
//			throw new DataNotFoundException("Subject [" + as_SubjectCode + "] is not found.");
//		}
		try {
			StringBuffer sb_SQLCommand = new StringBuffer();
			sb_SQLCommand.append("SELECT SJ.* ");
			sb_SQLCommand.append("FROM Subject SJ ");
			
			sb_SQLCommand.append(PermissionService.GetJoinString("SJ.SJ_OwnerGroupID", SUID, SGID));
			sb_SQLCommand.append("WHERE SJ.SJ_CreateTime IS NOT NULL ");
			if(as_SubjectCode != null){
				sb_SQLCommand.append("AND SJ.SJ_Code = '" + as_SubjectCode+"' ");
			}
			
			sb_SQLCommand.append("AND SJ.SJ_DataStatus NOT IN ( ");
			sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
			sb_SQLCommand.append(", ");
			sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
			if (StatusList.length > 0) {
				for (int i = 0; i < StatusList.length; i++) {
					sb_SQLCommand.append(", ");
					sb_SQLCommand.append(StatusList[i]);
				}
			}
			sb_SQLCommand.append(") ");
			sb_SQLCommand.append(PermissionService.GetWhereString("SJ.SJ_OwnerUserID", SUID, SGID));
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetByCode", sb_SQLCommand.toString());
			NativeQuery<Subject> query = MyHSs.createSQLQuery(sb_SQLCommand.toString()).addEntity(Subject.class);
			query.setFirstResult(0);
			query.setMaxResults(1);
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList.get(0);
			} else {
				CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetByCode", "[Not Found] @@@");
				throw new DataNotFoundException("Get Subject By Code ["+as_SubjectCode+ " ] is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	
	/**
	 * @param ai_CommandType
	 * @param SUID
	 * @param SGID
	 * @param StatusList
	 * @return
	 */
	public static String GenSQLALL(int ai_CommandType, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT SJ.* ");
		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		return sb_SQLCommand.toString();
	}
	/**
	 * @param MyHSs
	 * @param SUID
	 * @param SGID
	 * @param StatusList
	 * @return
	 * @throws DataNotFoundException
	 * @throws Exception
	 */
	public static int GetSizeAll(Session MyHSs,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeAll", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLALL(10,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeAll", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeAll", "[" + RowCount.intValue() + "] Of Subject By All [END] @@@");
		return RowCount.intValue();
	}
	/**
	 * @param MyHSs
	 * @param SUID
	 * @param SGID
	 * @param BeginRow
	 * @param MaxRow
	 * @param StatusList
	 * @return
	 * @throws DataNotFoundException
	 * @throws Exception
	 */
	public static List<Subject> FindAll(Session MyHSs,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByAll", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLALL(20,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByAll", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindByAll", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By All is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	
	
	public static String GenSQLBySubjectCodeSubjectName(int ai_CommandType,String as_SubjectCode , String as_SubjectName, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT SJ.* ");
		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		
		if(as_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = '"+as_SubjectCode+"' ");
		}
		if(as_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name LIKE '%"+as_SubjectName+"%' ");
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY SJ.SJ_Code , SJ.SJ_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySubjectCodeSubjectName(Session MyHSs,String as_SubjectCode , String as_SubjectName,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectName", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySubjectCodeSubjectName(10,as_SubjectCode , as_SubjectName, SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectName", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectName", "[" + RowCount.intValue() + "] Of Subject By SubjectCode And SubjectName [SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Subject> FindBySubjectCodeSubjectName(Session MyHSs,String as_SubjectCode , String as_SubjectName,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByBySubjectCodeSubjectName", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySubjectCodeSubjectName(20,as_SubjectCode , as_SubjectName,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectName", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectName[SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+"]", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By SubjectCode And SubjectName is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	public static String GenSQLBySubjectCodeSubjectNameFilterExamScheduleID(int ai_CommandType,String as_SubjectCode , String as_SubjectName,Integer ai_FilterExamScheduleID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT SJ.* ");
		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		
		if(as_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = '"+as_SubjectCode+"' ");
		}
		if(as_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name LIKE '%"+as_SubjectName+"%' ");
		}
		if(ai_FilterExamScheduleID != null){
			sb_SQLCommand.append("AND SJ.SubjectID NOT IN ( ");
				sb_SQLCommand.append("SELECT ESD.ESD_SubjectID ");
				sb_SQLCommand.append("FROM ExamSchedule ES ");
				sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ESD_CopiedExamScheduleID = ES.ExamScheduleID ");
				sb_SQLCommand.append("WHERE ES.ES_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ES.ExamScheduleID = "+ai_FilterExamScheduleID+" ");
			sb_SQLCommand.append(" ) ");
			
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY SJ.SJ_Code , SJ.SJ_Name ");
		}
		
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySubjectCodeSubjectNameFilterExamScheduleID(Session MyHSs,String as_SubjectCode , String as_SubjectName,Integer ai_FilterExamScheduleID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNameFilterExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySubjectCodeSubjectNameFilterExamScheduleID(10,as_SubjectCode , as_SubjectName,ai_FilterExamScheduleID, SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNameFilterExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNameFilterExamScheduleID", "[" + RowCount.intValue() + "] Of Subject By SubjectCode And SubjectName [SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+",FilterExamScheduleID:"+ai_FilterExamScheduleID+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Subject> FindBySubjectCodeSubjectNameFilterExamScheduleID(Session MyHSs,String as_SubjectCode , String as_SubjectName,Integer ai_FilterExamScheduleID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByBySubjectCodeSubjectNameFilterExamScheduleID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySubjectCodeSubjectNameFilterExamScheduleID(20,as_SubjectCode , as_SubjectName,ai_FilterExamScheduleID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectNameFilterExamScheduleID", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectName[SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+"]", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By SubjectCode And SubjectName is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	public static String GenSQLBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID(int ai_CommandType,String as_SubjectCode , String as_SubjectName,TYPE_ENABLE_STATUS ae_EnableStatus ,Integer ai_FilterExamScheduleID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT SJ.* ");
		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		
		if(as_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = '"+as_SubjectCode+"' ");
		}
		if(as_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name LIKE '%"+as_SubjectName+"%' ");
		}
		if(ai_FilterExamScheduleID != null){
			sb_SQLCommand.append("AND SJ.SubjectID NOT IN ( ");
				sb_SQLCommand.append("SELECT ESD.ESD_SubjectID ");
				sb_SQLCommand.append("FROM ExamSchedule ES ");
				sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ESD_CopiedExamScheduleID = ES.ExamScheduleID ");
				sb_SQLCommand.append("WHERE ES.ES_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ESD.ESD_DataStatus NOT IN ( ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
				sb_SQLCommand.append(") ");
				sb_SQLCommand.append("AND ES.ExamScheduleID = "+ai_FilterExamScheduleID+" ");
			sb_SQLCommand.append(" ) ");
			
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY SJ.SJ_Code , SJ.SJ_Name ");
		}
		
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID(Session MyHSs,String as_SubjectCode , String as_SubjectName,TYPE_ENABLE_STATUS ae_EnableStatus,Integer ai_FilterExamScheduleID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID(10,as_SubjectCode , as_SubjectName,ae_EnableStatus,ai_FilterExamScheduleID, SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID", "[" + RowCount.intValue() + "] Of Subject By SubjectCode And SubjectName And EnableStatus [SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+",EnableStatus : "+ae_EnableStatus+",FilterExamScheduleID:"+ai_FilterExamScheduleID+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Subject> FindBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID(Session MyHSs,String as_SubjectCode , String as_SubjectName,TYPE_ENABLE_STATUS ae_EnableStatus,Integer ai_FilterExamScheduleID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID(20,as_SubjectCode , as_SubjectName,ae_EnableStatus,ai_FilterExamScheduleID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectNameEnableStatusFilterExamScheduleID", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectNameEnableStatus[SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+",EnableStatus : "+ae_EnableStatus+"]", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By SubjectCode And SubjectName And EnableStatus is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
public static String GenSQLByExamYearIDExamSemesterIDExamRoundIDExamTermIDSubjectCodeSubjectNameExaminationTypeExaminationStatus(int ai_CommandType,Integer ai_ExamYearID,Integer ai_ExamSemesterID,Integer ai_ExamRoundID,Integer ai_ExamTermID,String ai_SubjectCode,String ai_SubjectName,TYPE_EXAMINATION ae_ExaminationType,List<TYPE_EXAMINATION_STATUS> ae_ExaminationStatusList, Integer SUID, Integer SGID,int... StatusList) {
		
		StringBuffer sb_SQLCommand = new StringBuffer();
//		if (ai_CommandType == 10) {
//			sb_SQLCommand.append("SELECT COUNT(*) ");
//		} else {
			sb_SQLCommand.append("SELECT distinct SJ.* ");
//		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("JOIN ExamScheduleDetail ESD ON ESD.ESD_SubjectID = SJ.SubjectID ");
		sb_SQLCommand.append("JOIN ExamSchedule ES ON ES.ExamScheduleID = ESD.ESD_CopiedExamScheduleID ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		if(ai_ExamYearID != null){
			sb_SQLCommand.append("AND ES.ES_ExamYearID = "+ai_ExamYearID+" ");
		}
		if(ai_ExamSemesterID  != null){
			sb_SQLCommand.append("AND ES.ES_ExamSemesterID = "+ai_ExamSemesterID+" ");
		}
		if(ai_ExamRoundID  != null){
			sb_SQLCommand.append("AND ES.ES_ExamRoundID = "+ai_ExamRoundID+" ");
		}
		if(ai_ExamTermID  != null){
			sb_SQLCommand.append("AND ES.ES_ExamTermID = "+ai_ExamTermID+" ");
		}
		if(ai_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = "+ai_SubjectCode+" ");
		}
		if(ai_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name = "+ai_SubjectName+" ");
		}
		if(ae_ExaminationType != null){
			sb_SQLCommand.append("AND ES.ES_ExaminationType = "+ae_ExaminationType.getValue()+" ");
		}
		if(ae_ExaminationStatusList != null){
			if(ae_ExaminationStatusList.size() > 0){
				sb_SQLCommand.append("AND ES.ES_ExaminationStatus IN (  ");
				for(int i=0;i<ae_ExaminationStatusList.size();i++){
					if(i > 0){
						sb_SQLCommand.append(" , ");
					}
					sb_SQLCommand.append(ae_ExaminationStatusList.get(i).getValue());
				}
				sb_SQLCommand.append(" ) ");
			}
		}
		if (ai_CommandType != 10) {
			sb_SQLCommand.append("ORDER BY SJ.SJ_Code ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByExamYearIDExamSemesterIDExamRoundIDExamTermIDSubjectCodeSubjectNameExaminationTypeExaminationStatus(Session MyHSs,Integer ai_ExamYearID,Integer ai_ExamSemesterID,Integer ai_ExamRoundID,Integer ai_ExamTermID,String ai_SubjectCode,String ai_SubjectName,TYPE_EXAMINATION ae_ExaminationType,List<TYPE_EXAMINATION_STATUS> ae_ExaminationStatusList,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeByExamYearIDExamSemesterIDExamRoundIDSubjectCodeSubjectNameExaminationTypeExaminationStatus", "[BEGIN] @@@");
		
		String ls_SQLCommand = GenSQLByExamYearIDExamSemesterIDExamRoundIDExamTermIDSubjectCodeSubjectNameExaminationTypeExaminationStatus(10,ai_ExamYearID,ai_ExamSemesterID, ai_ExamRoundID,ai_ExamTermID,ai_SubjectCode,ai_SubjectName,ae_ExaminationType,ae_ExaminationStatusList,SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeByExamYearIDExamSemesterIDExamRoundIDSubjectCodeSubjectNameExaminationTypeExaminationStatus", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeByExamYearIDExamSemesterIDExamRoundIDSubjectCodeSubjectNameExaminationTypeExaminationStatus", "[" + RowCount.intValue() + "] Of Subject By All [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Subject> FindByExamYearIDExamSemesterIDExamRoundIDExamTermIDSubjectCodeSubjectNameExaminationTypeExaminationStatus(Session MyHSs,Integer ai_ExamYearID,Integer ai_ExamSemesterID,Integer ai_ExamRoundID,Integer ai_ExamTermID,String ai_SubjectCode,String ai_SubjectName,TYPE_EXAMINATION ae_ExaminationType,List<TYPE_EXAMINATION_STATUS> ae_ExaminationStatusList,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByExamYearIDExamSemesterIDExamRoundIDSubjectIDExaminationTypeExaminationStatus", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByExamYearIDExamSemesterIDExamRoundIDExamTermIDSubjectCodeSubjectNameExaminationTypeExaminationStatus(20,ai_ExamYearID,ai_ExamSemesterID, ai_ExamRoundID,ai_ExamTermID,ai_SubjectCode,ai_SubjectName,ae_ExaminationType,ae_ExaminationStatusList,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByExamYearIDExamSemesterIDExamRoundIDSubjectCodeSubjectNameExaminationTypeExaminationStatus", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindByExamYearIDExamSemesterIDExamRoundIDSubjectCodeSubjectNameExaminationTypeExaminationStatus", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By ExamYearIDExamSemesterIDExamRoundIDSubjectIDExaminationType ExaminationStatus is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	
	public static String GenSQLByCurriculumID(int ai_CommandType,Integer ai_CurriculumID, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT SJ.* ");
		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		
		if(ai_CurriculumID != null){
			sb_SQLCommand.append("AND SJ.SJ_CurriculumID = '"+ai_CurriculumID+"' ");
		}
		
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY SJ.SJ_Code , SJ.SJ_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeByCurriculumID(Session MyHSs,Integer ai_CurriculumID,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeByCurriculumID", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLByCurriculumID(10,ai_CurriculumID, SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeByCurriculumID", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeByCurriculumID", "[" + RowCount.intValue() + "] Of Subject By SubjectCode And SubjectName [CurriculumID:"+ai_CurriculumID+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Subject> FindByCurriculumID(Session MyHSs,Integer ai_CurriculumID,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByByCurriculumID", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLByCurriculumID(20,ai_CurriculumID,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindByCurriculumID", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindByCurriculumID[CurriculumID:"+ai_CurriculumID+"]", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By SubjectCode And SubjectName is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
	public static String GenSQLBySubjectCodeSubjectNamePersonIDExaminationStatusList(int ai_CommandType,String as_SubjectCode , String as_SubjectName,Integer ai_PersonID,List<TYPE_EXAMINATION_STATUS> ae_ExaminationStatusList, Integer SUID, Integer SGID,int... StatusList) {
		StringBuffer sb_SQLCommand = new StringBuffer();
		if (ai_CommandType == 10) {
			sb_SQLCommand.append("SELECT COUNT(*) ");
		} else {
			sb_SQLCommand.append("SELECT SJ.* ");
		}
		sb_SQLCommand.append("FROM Subject SJ ");
		sb_SQLCommand.append("WHERE SJ.SJ_DataStatus NOT IN ( ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DISABLE.getValue());
		sb_SQLCommand.append(", ");
		sb_SQLCommand.append(TYPE_DATA_STATUS.STATUS_DELETE.getValue());
		if (StatusList.length > 0) {
			for (int i = 0; i < StatusList.length; i++) {
				sb_SQLCommand.append(", ");
				sb_SQLCommand.append(StatusList[i]);
			}
		}
		sb_SQLCommand.append(") ");
		
		if(as_SubjectCode != null){
			sb_SQLCommand.append("AND SJ.SJ_Code = '"+as_SubjectCode+"' ");
		}
		if(as_SubjectName != null){
			sb_SQLCommand.append("AND SJ.SJ_Name LIKE '%"+as_SubjectName+"%' ");
		}
		if(ai_PersonID != null){
			sb_SQLCommand.append("AND SJ.SubjectID IN (SELECT UN.UN_SubjectID FROM Unit UN  ");
			sb_SQLCommand.append(" JOIN ExamCreatorCondition ECCD ON ECCD.ECCD_UnitID = UN.UnitID ");
			sb_SQLCommand.append(" JOIN ExamFormCondition EFCD ON EFCD.ExamFormConditionID = ECCD.ECCD_ExamFormConditionID  AND EFCD.EFCD_DataStatus NOT IN (411,511) ");
			sb_SQLCommand.append(" JOIN ExamScheduleDetail ESD ON ESD.ExamScheduleDetailID = EFCD.EFCD_ExamScheduleDetailID AND ESD.ESD_DataStatus NOT IN (411,511) ");
			sb_SQLCommand.append(" JOIN ExamSchedule ES ON ES.ExamScheduleID = ESD.ESD_CopiedExamScheduleID AND ES.ES_DataStatus NOT IN (411,511) ");
			sb_SQLCommand.append(" JOIN Person PS ON PS.PersonID = ECCD.ECCD_PersonID AND PS.PS_DataStatus NOT IN (411,511) ");
			sb_SQLCommand.append(" WHERE ECCD.ECCD_DataStatus NOT IN (411,511) ");
			if(ai_PersonID != null){
				sb_SQLCommand.append("AND PS.PS_SystemUserID = "+ai_PersonID+" ");
			}
			if(ae_ExaminationStatusList != null){
				if(ae_ExaminationStatusList.size() > 0){
					sb_SQLCommand.append("AND ES.ES_ExaminationStatus IN (  ");
					for(int i=0;i<ae_ExaminationStatusList.size();i++){
						if(i > 0){
							sb_SQLCommand.append(" , ");
						}
						sb_SQLCommand.append(ae_ExaminationStatusList.get(i).getValue());
					}
					sb_SQLCommand.append(" ) ");
				}
			}
			sb_SQLCommand.append(" AND ECCD.ECCD_NOFItem IS NOT NULL AND ECCD.ECCD_NOFItem > 0 ");
			sb_SQLCommand.append(" ) ");
		}
		if(ai_CommandType != 10){
			sb_SQLCommand.append("ORDER BY SJ.SJ_Code , SJ.SJ_Name ");
		}
		return sb_SQLCommand.toString();
	}
	
	public static int GetSizeBySubjectCodeSubjectNamePersonIDExaminationStatusList(Session MyHSs,String as_SubjectCode , String as_SubjectName,Integer ai_PersonID,List<TYPE_EXAMINATION_STATUS> ae_ExaminationStatusList,Integer SUID, Integer SGID,int... StatusList) throws DataNotFoundException, Exception {
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNamePersonIDExaminationStatusList", "[BEGIN] @@@");
		String ls_SQLCommand = GenSQLBySubjectCodeSubjectNamePersonIDExaminationStatusList(10,as_SubjectCode , as_SubjectName,ai_PersonID,ae_ExaminationStatusList, SUID,SGID,StatusList);
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNamePersonIDExaminationStatusList", ls_SQLCommand);
		Integer RowCount = (Integer) MyHSs.createSQLQuery(ls_SQLCommand).uniqueResult();
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "GetSizeBySubjectCodeSubjectNamePersonIDExaminationStatusList", "[" + RowCount.intValue() + "] Of Subject By SubjectCode And SubjectName [SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+"] [END] @@@");
		return RowCount.intValue();
	}
	
	public static List<Subject> FindBySubjectCodeSubjectNamePersonIDExaminationStatusList(Session MyHSs,String as_SubjectCode , String as_SubjectName,Integer ai_PersonID,List<TYPE_EXAMINATION_STATUS> ae_ExaminationStatusList,Integer SUID,Integer SGID, int BeginRow, int MaxRow,int... StatusList) throws DataNotFoundException, Exception {
		assert BeginRow < 0 : "BeginRow is less than 0";
		assert MaxRow < 0 : "MaxRow is less than 0";
		CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectNamePersonIDExaminationStatusList", "[START] @@@");
		try {
			String ls_SQLCommand =  GenSQLBySubjectCodeSubjectNamePersonIDExaminationStatusList(20,as_SubjectCode , as_SubjectName,ai_PersonID,ae_ExaminationStatusList,SUID,SGID,StatusList);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectNamePersonIDExaminationStatusList", ls_SQLCommand);
			NativeQuery<Subject> query = MyHSs.createSQLQuery(ls_SQLCommand).addEntity(Subject.class);
			query.setFirstResult(BeginRow);
			if (MaxRow > 0) {
				query.setMaxResults(MaxRow);
			}
			List<Subject> SubjectList = query.list();
			if (SubjectList.isEmpty() != true) {
				return SubjectList;
			} else {
				CommonLog.Print(LOG_LEVEL.ERROR_LEVEL, "SubjectDAO", "FindBySubjectCodeSubjectNamePersonIDExaminationStatusList[SubjectCode:"+as_SubjectCode+",SubjectName:"+as_SubjectName+"]", "[Not Found] @@@");
				throw new DataNotFoundException("Find Subject By SubjectCode And SubjectName is not found.");
			}
		} catch (Exception ex) {
			ex.printStackTrace();
			throw ex;
		} finally {
		}
	}
}