package esi.examwh.dao.util;

import java.util.EnumSet;
import java.util.PropertyResourceBundle;

import esi.examwh.dao.common.CommonLog;
import esi.examwh.dao.common.LOG_LEVEL;

import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.boot.Metadata;
import org.hibernate.boot.MetadataSources;
import org.hibernate.boot.registry.StandardServiceRegistry;
import org.hibernate.boot.registry.StandardServiceRegistryBuilder;
import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaExport;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;
import org.hibernate.tool.hbm2ddl.SchemaValidator;
import org.hibernate.tool.schema.TargetType;


public class ExamWHDaoUtil {
	private static final SessionFactory sessionFactory;
	private static final StandardServiceRegistry serviceRegistry;
	private static final Configuration cfg;
	private static final Metadata metadata;
	private static final MetadataSources sources;
	static {
		String ls_urlDB = "";
		String ls_userDB = "";
		String ls_passwordDB = "";
		String ls_max_size = "100";
		String ls_min_size = "40";
		String ls_show_sql = "false";
		String ls_level_cache = "true";
		String ls_query_cache = "true";
		String connection_pool = "true";
		try {
			PropertyResourceBundle propResBundle = new PropertyResourceBundle(Thread.currentThread().getContextClassLoader().getResourceAsStream("config.properties"));
			ls_urlDB = propResBundle.getString("urldb");
			ls_userDB = propResBundle.getString("userdb");
			ls_passwordDB = propResBundle.getString("passworddb");
			ls_max_size = propResBundle.getString("max_size");
			ls_min_size = propResBundle.getString("min_size");
			ls_show_sql = propResBundle.getString("show_sql");
			ls_level_cache = propResBundle.getString("level_cache");
			ls_query_cache = propResBundle.getString("query_cache");
			connection_pool = propResBundle.getString("connection_pool");
			// ls_passwordDB = Common.Decrypt(ls_passwordDB);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "WiexDAOUtil", "OpenConnection", "urlDB="+ls_urlDB);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "WiexDAOUtil", "OpenConnection", "userDB="+ls_userDB);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "WiexDAOUtil", "OpenConnection", "passwordDB="+ls_passwordDB);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "WiexDAOUtil", "OpenConnection", "maxSize="+ls_max_size);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "WiexDAOUtil", "OpenConnection", "minSize="+ls_min_size);
			CommonLog.Print(LOG_LEVEL.INFO_LEVEL, "WiexDAOUtil", "OpenConnection", "connection_pool="+connection_pool);
		} catch (Exception ex) {
			System.out.println("load Properties File");
			ex.printStackTrace();
		}

		try {
			cfg = new Configuration();
			cfg.addAnnotatedClass(esi.examwh.model.BehaviorLevel.class);
			cfg.addAnnotatedClass(esi.examwh.model.EsdformCollator.class);
			cfg.addAnnotatedClass(esi.examwh.model.ESDFormCollatorPK.class);
			cfg.addAnnotatedClass(esi.examwh.model.ESDItemSelector.class);
			cfg.addAnnotatedClass(esi.examwh.model.ESDItemSelectorPK.class);
			cfg.addAnnotatedClass(esi.examwh.model.EsdformEditor.class);
			cfg.addAnnotatedClass(esi.examwh.model.ESDFormEditorPK.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamAnalysis.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamAnalysisHistogram.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamAnalysisUnitStat.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamAnalysisCtt.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamAnalysisIrt.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamForm.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormAnalysisHistory.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormCommand.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormDocument.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormItem.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormItemChoice.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormItemGroup.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormOperationLog.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.ExamItem.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemChoice.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemDocument.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemGroup.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemGroupDocument.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemHistory.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamRound.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamSchedule.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamScheduleDetail.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamSemester.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamTerm.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamYear.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.Objective.class);
			cfg.addAnnotatedClass(esi.examwh.model.Person.class);
			cfg.addAnnotatedClass(esi.examwh.model.Section.class);
			cfg.addAnnotatedClass(esi.examwh.model.Subject.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectCollator.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectCollatorPK.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectDocument.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectEditor.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectEditorPK.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectFormPolicy.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectFormPolicyDetail.class);
			cfg.addAnnotatedClass(esi.examwh.model.SubjectFormPolicySubDetail.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.TableMapping.class);
			cfg.addAnnotatedClass(esi.examwh.model.TableMappingDetail.class);
			cfg.addAnnotatedClass(esi.examwh.model.TableMappingSubDetail.class);
			cfg.addAnnotatedClass(esi.examwh.model.Topic.class);
			cfg.addAnnotatedClass(esi.examwh.model.TopicObjective.class);
			cfg.addAnnotatedClass(esi.examwh.model.Unit.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.DocumentNumber.class);
			cfg.addAnnotatedClass(esi.examwh.model.DocumentNumberPK.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.ExamTimes.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamTimesPK.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.Curriculum.class);
			cfg.addAnnotatedClass(esi.examwh.model.Attributes.class);
			cfg.addAnnotatedClass(esi.examwh.model.CurriculumAttribute.class);
			cfg.addAnnotatedClass(esi.examwh.model.Indicators.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemAttribute.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemSelected.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormCondition.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamItemCondition.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamCreatorCondition.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamScheduleDetailSelected.class);
			cfg.addAnnotatedClass(esi.examwh.model.ExamFormSelected.class);
			cfg.addAnnotatedClass(esi.examwh.model.ActionType.class);
			cfg.addAnnotatedClass(esi.examwh.model.UserActionLog.class);
			
			cfg.addAnnotatedClass(esi.examwh.model.RemunerationCalculate.class);
			cfg.addAnnotatedClass(esi.examwh.model.StandardRemuneration.class);
			cfg.addAnnotatedClass(esi.examwh.model.RemunerationCalculateItem.class);
			cfg.addAnnotatedClass(esi.examwh.model.MainSelector.class);
			cfg.addPackage("esi.examwh.model");
			if (connection_pool.equals("HikariCP")) {
				cfg.setProperty("hibernate.bytecode.use_reflection_optimizer", "true");
				cfg.setProperty("hibernate.connection.driver_class", "com.microsoft.sqlserver.jdbc.SQLServerDriver");
				cfg.setProperty("hibernate.connection.url", ls_urlDB);
//				cfg.setProperty("hibernate.connection.url", "jdbc:sqlserver://localhost:2019;databaseName=AFSEngineREAL_2022_10_10;integratedSecurity=false;applicationName=AFS;");
				cfg.setProperty("hibernate.connection.username", ls_userDB);
				cfg.setProperty("hibernate.connection.password", ls_passwordDB);
				cfg.setProperty("hibernate.cache.use.second_level_cache", ls_level_cache);
				cfg.setProperty("hibernate.cache.use.query_cache", ls_query_cache);
				cfg.setProperty("hibernate.show_sql", ls_show_sql);
				cfg.setProperty("hibernate.connection.isolation", "1");
				
//				cfg.setProperty("hibernate.cache.use_second_level_cache","true");
//				cfg.setProperty("hibernate.cache.region.factory_class","org.hibernate.cache.ehcache.EhCacheRegionFactory");
				
//				cfg.setProperty("hibernate.cache.region.factory_class","org.hibernate.cache.ehcache.SingletonEhCacheRegionFactory");
//				cfg.setProperty("hibernate.connection.shutdown", "true");
//				cfg.setProperty("hibernate.connection.writedelay", "0");
//				cfg.setProperty("hibernate.connection.release_mode", "on_close");
				cfg.setProperty("hibernate.connection.provider_disables_autocommit", "false");
				cfg.setProperty("hibernate.current_session_context_class", "thread");
				cfg.setProperty("hibernate.connection.handling_mode", "DELAYED_ACQUISITION_AND_RELEASE_AFTER_TRANSACTION");
//				cfg.setProperty("org.hibernate.stat", "fatal");
//				cfg.setProperty("hibernate.generate_statistics", Level.OFF.getName());
				
				cfg.setProperty("hibernate.connection.provider_class", "org.hibernate.hikaricp.internal.HikariCPConnectionProvider");
				// Maximum waiting time for a connection from the pool
				cfg.setProperty("hibernate.hikari.connectionTimeout", "20000");
				// Minimum number of ideal connections in the pool
				cfg.setProperty("hibernate.hikari.minimumIdle", ls_min_size);
//				// Minimum number of actual connection in the pool
//				cfg.setProperty("hibernate.hikari.minimumPoolSize", ls_min_size);
				// Maximum number of actual connection in the pool
				cfg.setProperty("hibernate.hikari.maximumPoolSize", ls_max_size);
				// Maximum time that a connection is allowed to sit ideal in the pool
				cfg.setProperty("hibernate.hikari.idleTimeout", "300000");
				cfg.setProperty("hibernate.hikari.poolName", "AFSConnPool");
				cfg.setProperty("hibernate.hikari.connectionTestQuery", "SELECT 1");

			} else {
				cfg.setProperty("hibernate.bytecode.use_reflection_optimizer", "true");
				cfg.setProperty("hibernate.connection.driver_class", "com.microsoft.sqlserver.jdbc.SQLServerDriver");
				cfg.setProperty("hibernate.connection.url", ls_urlDB);
//				cfg.setProperty("hibernate.connection.url", "jdbc:sqlserver://localhost:2019;databaseName=AFSEngineREAL_2022_10_10;integratedSecurity=false;applicationName=AFS;");
				cfg.setProperty("hibernate.connection.username", ls_userDB);
				cfg.setProperty("hibernate.connection.password", ls_passwordDB);
				cfg.setProperty("hibernate.cache.use.second_level_cache", ls_level_cache);
				cfg.setProperty("hibernate.cache.use.query_cache", ls_query_cache);
				cfg.setProperty("hibernate.show_sql", ls_show_sql);
				cfg.setProperty("hibernate.connection.isolation", "1");
				
//				cfg.setProperty("hibernate.cache.use_second_level_cache","true");
//				cfg.setProperty("hibernate.cache.region.factory_class","org.hibernate.cache.ehcache.EhCacheRegionFactory");
				
//				cfg.setProperty("hibernate.connection.shutdown", "true");
//				cfg.setProperty("hibernate.connection.writedelay", "0");
//				cfg.setProperty("hibernate.connection.release_mode", "on_close");
				cfg.setProperty("hibernate.connection.provider_disables_autocommit", "false");
				cfg.setProperty("hibernate.current_session_context_class", "thread");
				cfg.setProperty("hibernate.connection.handling_mode", "DELAYED_ACQUISITION_AND_RELEASE_AFTER_TRANSACTION");
//				cfg.setProperty("org.hibernate.stat", "fatal");
//				cfg.setProperty("hibernate.generate_statistics", Level.OFF.getName());
				
				
				cfg.setProperty("hibernate.connection.provider_class","org.hibernate.service.jdbc.connections.internal.C3P0ConnectionProvider");
				cfg.setProperty("hibernate.c3p0.acquire_increment", "3");
				cfg.setProperty("hibernate.c3p0.idle_test_period", "0");
				cfg.setProperty("hibernate.c3p0.max_size", ls_max_size);
				cfg.setProperty("hibernate.c3p0.min_size", ls_min_size);
				cfg.setProperty("hibernate.c3p0.max_statements", "0");
				cfg.setProperty("hibernate.c3p0.timeout", "0");
				
			}
			
//			cfg.setProperty("hibernate.hbm2ddl.auto", "validate");
//			cfg.setProperty("hibernate.hbm2ddl.auto", "update");
//			cfg.setProperty("hibernate.current_session_context_class", "thread");

			cfg.setProperty("hibernate.dialect", "esi.examwh.dao.util.ESISQLServerDialect");
			
			serviceRegistry = new StandardServiceRegistryBuilder().applySettings(cfg.getProperties()).build();
			StandardServiceRegistryBuilder ssrb = new StandardServiceRegistryBuilder().applySettings(cfg.getProperties());
			
			sources = new MetadataSources(serviceRegistry);
			metadata = sources.buildMetadata(serviceRegistry);
		    sessionFactory = cfg.buildSessionFactory(ssrb.build());
		} catch (Throwable ex) {
			ex.printStackTrace();
			throw new ExceptionInInitializerError(ex);
		}
//		SchemaUpdate();
	}

	public static void SchemaExport() {
		SchemaExport schemaExport = new SchemaExport();
		schemaExport.setOutputFile("db-schema.hibernate5.ddl");
		schemaExport.create(EnumSet.of(TargetType.SCRIPT), metadata);
		metadata.buildSessionFactory().close();
	}

	public static void SchemaUpdate() {
		SchemaUpdate schemaUpdate = new SchemaUpdate();
		EnumSet<TargetType> targetTypes = EnumSet.of(TargetType.DATABASE);
		schemaUpdate.execute(targetTypes, metadata, serviceRegistry);
	}

	public static void SchemaValidate() {
		SchemaValidator schemaValidator = new SchemaValidator();
		schemaValidator.validate(metadata,serviceRegistry);
	}

	public static Session getSession() throws HibernateException {
		return sessionFactory.openSession();
	}

	public static Session getCurrentSession() throws HibernateException {
		return sessionFactory.getCurrentSession();
	}


	public static void main(String[] argv) {
		//ExamWHDaoUtil.SchemaExport();
		ExamWHDaoUtil.SchemaUpdate();
//		ExamWHDaoUtil.SchemaValidate();
//		if (argv.length > 0) {
//			String CLICommand = argv[0].toUpperCase();
//			if (CLICommand.equals("Export".toUpperCase())) {
//				System.out.println("Export Mode");
//				// HibernateUtil.SchemaExport();
//			} else if (CLICommand.equals("Update".toUpperCase())) {
//				System.out.println("Update Mode");
//				// HibernateUtil.SchemaUpdate();
//			} else if (CLICommand.equals("Validate".toUpperCase())) {
//				System.out.println("Validate Mode");
//				// HibernateUtil.SchemaValidate();
//			} else {
//				System.out.println("java -jar xx.jar nbd.util.HibernateUtil [Export, Update, Validate]");
//			}
//		}
	}
}
